Index: pkg/compiler/lib/src/resolution/signatures.dart |
diff --git a/pkg/compiler/lib/src/resolution/signatures.dart b/pkg/compiler/lib/src/resolution/signatures.dart |
index 33a8f2f336bb0a62d8683a7c5e32d3a580581636..129262c97650bb2d5d9aabb59183fe7b6c173817 100644 |
--- a/pkg/compiler/lib/src/resolution/signatures.dart |
+++ b/pkg/compiler/lib/src/resolution/signatures.dart |
@@ -314,10 +314,11 @@ class SignatureResolver extends MappingVisitor<FormalElementX> { |
nodes = nodes.tail; |
TypeVariableElementX variableElement = |
new TypeVariableElementX(variableName, element, index, node); |
// TODO(eernst): When type variables are implemented fully we will need |
// to resolve the actual bounds; currently we just claim [dynamic]. |
variableElement.boundCache = const DynamicType(); |
- TypeVariableType variableType = new TypeVariableType(variableElement); |
+ TypeVariableType variableType = |
+ new MethodTypeVariableType(variableElement); |
variableElement.typeCache = variableType; |
return variableType; |
}, growable: false); |
@@ -314,10 +314,11 @@ class SignatureResolver extends MappingVisitor<FormalElementX> { |
TypeVariableElementX variableElement = |
new TypeVariableElementX(variableName, element, index, node); |
- // TODO(eernst): When type variables are implemented fully we will need |
- // to resolve the actual bounds; currently we just claim [dynamic]. |
+ // TODO(eernst): When method type variables are implemented fully we |
+ // must resolve the actual bounds; currently we just claim [dynamic]. |
variableElement.boundCache = const DynamicType(); |